import { Config } from 'windicss/types/interfaces';

interface RequiredOptions {
    priorityOrderList: Array<string>;
    sortOrder: 'asc' | 'desc';
    sortUnknowns: boolean;
    unknownClassNamesPosition: 'start' | 'end';
    removeDuplicateClassNames: boolean;
    useVariantGroup: boolean;
    config?: string | Config;
}
interface Options {
    /** __List of classes to be sorted preferentially__ */
    priorityOrderList?: RequiredOptions['priorityOrderList'];
    /** __Standard sort order__ */
    sortOrder?: RequiredOptions['sortOrder'];
    /** __Whether to sort unknown classes__ */
    sortUnknowns?: RequiredOptions['sortUnknowns'];
    /** __Position of unknown classes__ */
    unknownClassNamesPosition?: RequiredOptions['unknownClassNamesPosition'];
    /** __Remove duplicate classes__
     *
     * if the same class name exists, remove it
     */
    removeDuplicateClassNames?: RequiredOptions['removeDuplicateClassNames'];
    /**
     * __Set how to write variants__
     *
     * true: `"sm:text-lg"` -> `"sm:(text-lg)"`
     *
     * false: `"sm:(text-lg)"` -> `"sm:text-lg"`
     */
    useVariantGroup?: RequiredOptions['useVariantGroup'];
    config?: RequiredOptions['config'];
}

declare class WindiSorter {
    priorityOrderList: RequiredOptions['priorityOrderList'];
    sortOrder: RequiredOptions['sortOrder'];
    sortUnknowns: RequiredOptions['sortUnknowns'];
    unknownClassNamesPosition: RequiredOptions['unknownClassNamesPosition'];
    removeDuplicateClassNames: RequiredOptions['removeDuplicateClassNames'];
    useVariantGroup: RequiredOptions['useVariantGroup'];
    config: RequiredOptions['config'];
    private processor;
    constructor(opts?: Options);
    private getWindiVariants;
    sortClassNames(classNames: string): string;
}

export default WindiSorter;
